function f = dCdT_exponential(~,c,F,V)
% FUNCTION DCDT(C)
%  Inputs: ~ - placeholder
%          c - concentration (M)
%          V - volume (constant, L)
%          F - flow (constant, L/sec)
%  Outputs: f - concentration time derivative
%              {dc/dt}
f = -(F/V)*c; 